@@ -68,6 +68,9 @@ async def pixivURL(bot: Bot, event: Event):
     pid = re.findall("https://www.pixiv.net/artworks/(\d+)|illust_id=(\d+)", str(event.get_message()))
     if pid:
         pid = [x for x in pid[0] if x][0]
+        if (not pixiv_r18) and  await pan_R18(pid):
+            await bot.send(event=event,message="不支持R18，请修改配置后操作！")
+            return
         xx = (await checkGIF(pid))
         if xx != "NO":
             await GIF_send(xx, pid, event, bot)
